==> mupif-0.11.5.tar.gz: mupif-0.11.5/mupif/examples/Example02/server.py <==
# This script starts a server for Pyro4 on this machine with Application2
# Works with Pyro4 version 4.28
# Tested on Ubuntu 14.04 and Win XP
# Vit Smilauer 09/2014, vit.smilauer (et) fsv.cvut.cz

# If firewall is blocking daemonPort, run on Ubuntu
# sudo iptables -A INPUT -p tcp -d 0/0 -s 0/0 --dport 44382 -j ACCEPT

#where is a running nameserver
nshost = "127.0.0.1"
nsport = 9091
#address where this server will listen through a daemon
daemonHost = "127.0.0.1"
daemonPort = 44382
hkey = 'mmp-secret-key'

import sys
sys.path.append('../../..')
from mupif import *
import logging
logger = logging.getLogger()
import socket
import Pyro4

Pyro4.config.SERIALIZER="pickle"
Pyro4.config.PICKLE_PROTOCOL_VERSION=2 #to work with python 2.x and 3.x
Pyro4.config.SERIALIZERS_ACCEPTED={'pickle'}


class application2(Application.Application):
    """
    Simple application that computes an arithmetical average of mapped property
    """
    def __init__(self, file):
        super(application2, self).__init__(file)
        self.value = 0.0
        self.count = 0.0
        self.contrib = 0.0
    def getProperty(self, propID, time, objectID=0):
        if (propID == PropertyID.PID_CumulativeConcentration):
            return Property.Property(float(self.value)/self.count, PropertyID.PID_CumulativeConcentration, ValueType.Scalar, time, propID, 0)
        else:
            raise APIError.APIError ('Unknown property ID')
    def setProperty(self, property, objectID=0):
        if (property.getPropertyID() == PropertyID.PID_Concentration):
            # remember the mapped value
            self.contrib = property.getValue()
        else:
            raise APIError.APIError ('Unknown property ID')
    def solveStep(self, tstep, stageID=0, runInBackground=False):
        # here we actually accumulate the value using value of mapped property
        self.value=self.value+self.contrib
        self.count = self.count+1

    def getCriticalTimeStep(self):
        return 1.0

#locate nameserver
ns = PyroUtil.connectNameServer(nshost, nsport, hkey)

#Run a daemon. It will run even the port has DROP/REJECT status. The connection from a client is then impossible.
daemon = Pyro4.Daemon(host=daemonHost, port=daemonPort)

app2 = application2("input2.in")
#register agent
uri = daemon.register(app2)
ns.register("Mupif.application2", uri)
print (uri)
daemon.requestLoop()

==> mupif-0.11.6.tar.gz: mupif-0.11.6/mupif/examples/Example02/server.py <==
from __future__ import print_function, division
# This script starts a server for Pyro4 on this machine with Application2
# Works with Pyro4 version 4.28
# Tested on Ubuntu 14.04 and Win XP
# Vit Smilauer 09/2014, vit.smilauer (et) fsv.cvut.cz

# If firewall is blocking daemonPort, run on Ubuntu
# sudo iptables -A INPUT -p tcp -d 0/0 -s 0/0 --dport 44382 -j ACCEPT

#where is a running nameserver
nshost = "127.0.0.1"
nsport = 9091
#address where this server will listen through a daemon
daemonHost = "127.0.0.1"
daemonPort = 44382
hkey = 'mmp-secret-key'

import sys
sys.path.append('../../..')
from mupif import *
import logging
logger = logging.getLogger()
import socket
import Pyro4

Pyro4.config.SERIALIZER="pickle"
Pyro4.config.PICKLE_PROTOCOL_VERSION=2 #to work with python 2.x and 3.x
Pyro4.config.SERIALIZERS_ACCEPTED={'pickle'}


class application2(Application.Application):
    """
    Simple application that computes an arithmetical average of mapped property
    """
    def __init__(self, file):
        super(application2, self).__init__(file)
        self.value = 0.0
        self.count = 0.0
        self.contrib = 0.0
    def getProperty(self, propID, time, objectID=0):
        if (propID == PropertyID.PID_CumulativeConcentration):
            return Property.Property(self.value/self.count, PropertyID.PID_CumulativeConcentration, ValueType.Scalar, time, propID, 0)
        else:
            raise APIError.APIError ('Unknown property ID')
    def setProperty(self, property, objectID=0):
        if (property.getPropertyID() == PropertyID.PID_Concentration):
            # remember the mapped value
            self.contrib = property.getValue()
        else:
            raise APIError.APIError ('Unknown property ID')
    def solveStep(self, tstep, stageID=0, runInBackground=False):
        # here we actually accumulate the value using value of mapped property
        self.value=self.value+self.contrib
        self.count = self.count+1

    def getCriticalTimeStep(self):
        return 1.0

#locate nameserver
ns = PyroUtil.connectNameServer(nshost, nsport, hkey)

#Run a daemon. It will run even the port has DROP/REJECT status. The connection from a client is then impossible.
daemon = Pyro4.Daemon(host=daemonHost, port=daemonPort)

app2 = application2("input2.in")
#register agent
uri = daemon.register(app2)
ns.register("Mupif.application2", uri)
print (uri)
daemon.requestLoop()
